@@ -142,7 +142,8 @@ void AppModeHelper::setApplicationMode(ScribusMainWindow* scmw, ScribusDoc* doc,
 				scmw->charPalette->setEnabled(false, nullptr);
 				if (currItem != nullptr)
 				{
-					currItem->update();
+					currItem->layout();
+					doc->regionsChanged()->update(currItem->getVisualBoundingRect());
 					if (currItem->isTextFrame())
 						enableTextActions(false);
 					//		scrMenuMgr->setMenuEnabled("Item", true);
@@ -659,6 +660,8 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 			}
 			else
 			{
+				const ParagraphStyle& curStyle = currItem->itemText.defaultStyle();
+				doc->currentStyle.setContext(curStyle.context());
 				doc->currentStyle = currItem->itemText.defaultStyle();
 			}
 
@@ -836,7 +839,10 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 		{
 			PageItem* it = doc->m_Selection->itemAt(i);
 			if ((!it->isPolygon()) && (!it->isPolyLine()))
+			{
 				hPoly = false;
+				break;
+			}
 		}
 		(*a_scrActions)["itemCombinePolygons"]->setEnabled(hPoly);
 
