@@ -22,11 +22,18 @@ public:
 	ScLcms2ColorProfileImpl(ScColorMgmtEngine& engine, cmsHPROFILE lcmsProfile);
 	virtual ~ScLcms2ColorProfileImpl();
 
-	virtual bool isNull() const;
+	bool isNull() const override;
 
-	virtual eColorSpaceType colorSpace()  const;
-	virtual eProfileClass   deviceClass() const;
-	virtual QString         productDescription() const;
+	eColorSpaceType colorSpace() const override;
+	eColorSpaceType connectionSpace() const override;
+	eProfileClass   deviceClass() const override;
+
+	int channelsOfColorSpace() const override;
+	int channelsOfConnectionSpace() const override;
+
+	bool            isSuitableForOutput() const override;
+	QString         productDescription() const override;
+	bool            save(QByteArray& profileData) const override;
 
 protected:
 	cmsHPROFILE     m_profileHandle;
