@@ -198,6 +198,16 @@ ScFace::gid_type FtFace::char2CMap(uint ch) const
 	return gl;
 }
 
+ScFace::cid_type FtFace::glyphIndexToCID(ScFace::gid_type index) const
+{
+	FT_Face face = ftFace();
+
+	ScFace::cid_type cid = 0;
+	FT_Error err = FT_Get_CID_From_Glyph_Index(face, index, &cid);
+	if (err)
+		cid = index;
+	return cid;
+}
 
 void FtFace::loadGlyph(ScFace::gid_type gl) const
 {
@@ -211,7 +221,8 @@ void FtFace::loadGlyph(ScFace::gid_type gl) const
 		sDebug(QObject::tr("Font %1 has broken glyph %2").arg(fontFile).arg(gl));
 		m_glyphWidth[gl] = 1;
 	}
-	else {
+	else
+	{
 		qreal ww = qreal(face->glyph->metrics.horiAdvance) / m_uniEM;
 		qreal w  = (face->glyph->metrics.width + qAbs(qreal(face->glyph->metrics.horiBearingX))) / m_uniEM;
 		GRec.bbox_width = qMax(w, ww);
