@@ -115,6 +115,7 @@ void ScImgDataLoader_PS::loadEmbeddedProfile(const QString& fn, int /* page */)
 						if (prof.colorSpace() == ColorSpace_Cmyk)
 							m_profileComponents = 4;
 						m_imageInfoRecord.profileName = prof.productDescription();
+						m_imageInfoRecord.embeddedProfileName = m_imageInfoRecord.profileName;
 						m_imageInfoRecord.isEmbedded = true;
 						m_embeddedProfile = psdata;
 					}
@@ -406,7 +407,7 @@ bool ScImgDataLoader_PS::parseData(const QString& fn)
 								ts2 >> x >> y >> b >> h;
 								fakeHeader.width = qRound(b);
 								fakeHeader.height = qRound(h);
-								parseRessourceData(strPhot, fakeHeader, psdata.size());
+								parseResourceData(strPhot, fakeHeader, psdata.size());
 								m_imageInfoRecord.valid = (m_imageInfoRecord.PDSpathData.size()) > 0;
 								if (!m_imageInfoRecord.PDSpathData.empty())
 								{
@@ -670,7 +671,6 @@ bool ScImgDataLoader_PS::loadPicture(const QString& fn, int page, int gsRes, boo
 			{
 				m_image.load(tmpFile);
 				x = 0;
-				y = 0;
 				b = m_image.width() / gsRes * 72.0;
 				h = m_image.height() / gsRes * 72.0;
 			}
@@ -903,7 +903,6 @@ void ScImgDataLoader_PS::decodeA85(QByteArray &psdata, const QString& tmp)
 					psdata.resize(psdata.size()+1);
 					psdata[psdata.size()-1] = data;
 				}
-				quintet = 0;
 			}
 			break;
 		}
