@@ -34,18 +34,16 @@ class StoryEditor;
  */
 class SCRIBUS_API PluginManager : public QObject
 {
-
 	Q_OBJECT
 
 public:
-
 	PluginManager();
 	~PluginManager();
 
 	/*! \brief Static methods for loading, unloading plugins and resolving symbols
 	 These methods are platform independent, but each platform uses a different
 	 implementation. */
-	static void* loadDLL(const QString& plugin );
+	static void* loadDLL(const QString& plugin);
 	static void* resolveSym( void* plugin, const char* sym );
 	static void  unloadDLL( void* plugin );
 
@@ -77,10 +75,6 @@ public:
 	 */
 	void enablePluginActionsForSelection(ScribusMainWindow*);
 
-	/*! \brief Called when selection change
-	 */
-	void enablePluginActionsForSelection(ScribusDoc*);
-
 	/*! \brief Checks if is the plugin is in the plugin map, is loaded, and is enabled.
 	 *
 	 * \param pluginName name of plugin to get
@@ -141,14 +135,10 @@ public:
 	 */
 	QStringList pluginNames(bool includeDisabled = false, const char* inherits = nullptr) const;
 	
-	virtual void changeEvent(QEvent *e);
-
 public slots:
-
 	void languageChange();
 
 protected:
-
 	/**
 	 * \brief PluginData is structure for plugin related informations.
 	 * \param pluginFile path to the share library (with name).
@@ -175,6 +165,7 @@ protected:
 		ScPlugin* plugin;
 		bool enableOnStartup;
 		bool enabled;
+		QString version;
 	};
 
 	/*! \brief Init one plugin.
@@ -204,9 +195,6 @@ protected:
 	 DOES NOT destroy the ScPlugin instance or unload the plugin. */
 	void disablePlugin(PluginData & pda);
 
-	/*! \brief Runs plugin's languageChange() method, and returns main menu item text if one exists */
-	QString callDLLForNewLanguage(const PluginData & pluginData);
-
 	/*! \brief Shuts down one plug-in. The DLL may not be unloaded, but
 	 *         it is cleaned up and its ScPlugin instance is destroyed.
 	 *         The plug-in is marked unloaded in the map.
