@@ -7,7 +7,7 @@ for which a new license (GPL+exception) is in place.
 #include <QCompleter>
 #include <QComboBox>
 #include <QDebug>
-#include <QDirModel>
+#include <QFileSystemModel>
 #include <QFileDialog>
 #include <QImageWriter>
 #include <QToolTip>
@@ -26,13 +26,13 @@ for which a new license (GPL+exception) is in place.
 #include "util.h"
 
 ExportForm::ExportForm(QWidget* parent, ScribusDoc* doc, int size, int quality, const QString& type)
-	: QDialog(parent, nullptr), m_doc(doc), m_PageCount(doc->DocPages.count())
+	: QDialog(parent, Qt::WindowFlags()), m_doc(doc), m_PageCount(doc->DocPages.count())
 {
 	setupUi(this);
 	setModal(true);
 	prefs = PrefsManager::instance().prefsFile->getPluginContext("pixmapexport");
 
-	QDirModel * dirModel = new QDirModel(this);
+	QFileSystemModel* dirModel = new QFileSystemModel(this);
 	dirModel->setFilter(QDir::AllDirs);
 	outputDirectory->setCompleter(new QCompleter(dirModel, this));
 
