@@ -323,10 +323,11 @@ bool CdrPlug::convert(const QString& fn)
 {
 	importedColors.clear();
 	importedPatterns.clear();
+
 	QFile file(fn);
-	if ( !file.exists() )
+	if  (!file.exists())
 	{
-		qDebug() << "File " << QFile::encodeName(fn).data() << " does not exist" << endl;
+		qDebug() << "File " << QFile::encodeName(fn).data() << " does not exist";
 		return false;
 	}
 	QFileInfo fi = QFileInfo(fn);
