@@ -98,8 +98,8 @@ void ScBitReader::alignToWord()
 
 CgmPlug::CgmPlug(ScribusDoc* doc, int flags)
 {
-	tmpSel=new Selection(this, false);
-	m_Doc=doc;
+	tmpSel = new Selection(this, false);
+	m_Doc = doc;
 	importerFlags = flags;
 	interactive = (flags & LoadSavePlugin::lfInteractive);
 	progressDialog = nullptr;
@@ -139,7 +139,7 @@ QImage CgmPlug::readThumbnail(const QString& fName)
 		QImage tmpImage;
 		if (Elements.count() > 0)
 		{
-			for (int dre=0; dre<Elements.count(); ++dre)
+			for (int dre =0; dre < Elements.count(); ++dre)
 			{
 				tmpSel->addItem(Elements.at(dre), true);
 			}
@@ -173,15 +173,15 @@ bool CgmPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	bool ret = false;
 	CustColors.clear();
 	QFileInfo fi = QFileInfo(fNameIn);
-	if ( !ScCore->usingGUI() )
+	if (!ScCore->usingGUI())
 	{
 		interactive = false;
 		showProgress = false;
 	}
 	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
-	if ( showProgress )
+	if (showProgress)
 	{
-		ScribusMainWindow* mw=(m_Doc==nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
+		ScribusMainWindow* mw = (m_Doc==nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
 		QStringList barNames, barTexts;
 		barNames << "GI";
@@ -224,7 +224,7 @@ bool CgmPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	{
 		if (!m_Doc || (flags & LoadSavePlugin::lfCreateDoc))
 		{
-			m_Doc=ScCore->primaryMainWindow()->doFileNew(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false, 0, false, 0, 1, "Custom", true);
+			m_Doc = ScCore->primaryMainWindow()->doFileNew(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false, 0, false, 0, 1, "Custom", true);
 			ScCore->primaryMainWindow()->HaveNewDoc();
 			ret = true;
 			baseX = 0;
@@ -282,7 +282,7 @@ bool CgmPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 				if (!(flags & LoadSavePlugin::lfLoadAsPattern))
 				{
 					m_Doc->m_Selection->delaySignalsOn();
-					for (int dre=0; dre<Elements.count(); ++dre)
+					for (int dre = 0; dre < Elements.count(); ++dre)
 					{
 						m_Doc->m_Selection->addItem(Elements.at(dre), true);
 					}
@@ -298,7 +298,7 @@ bool CgmPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 				m_Doc->DraggedElem = nullptr;
 				m_Doc->DragElements.clear();
 				m_Doc->m_Selection->delaySignalsOn();
-				for (int dre=0; dre<Elements.count(); ++dre)
+				for (int dre = 0; dre < Elements.count(); ++dre)
 				{
 					tmpSel->addItem(Elements.at(dre), true);
 				}
@@ -488,7 +488,7 @@ bool CgmPlug::convert(const QString& fn)
 			{
 				tmpSel->clear();
 				tmpSel->delaySignalsOn();
-				for (int dre=0; dre<Elements.count(); ++dre)
+				for (int dre = 0; dre < Elements.count(); ++dre)
 				{
 					tmpSel->addItem(Elements.at(dre), true);
 				}
@@ -1102,10 +1102,7 @@ void CgmPlug::decodeClass3(QDataStream &ts, quint16 elemID, quint16 paramLen)
 	else if (elemID == 6)
 	{
 		ts >> data;
-		if (data == 0)
-			useClipRect = false;
-		else
-			useClipRect = true;
+		useClipRect = (data != 0);
 		// qDebug() << "CLIP INDICATOR" << useClipRect;
 	}
 	else if (elemID == 7)
@@ -1642,7 +1639,7 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QLineF n_i = s_i.normalVector();
 		n_i.translate(s_i.pointAt(0.5) - s_i.p1());
 		QPointF center;
-		if (n_s.intersect(n_i, &center) != QLineF::NoIntersection)
+		if (n_s.intersects(n_i, &center) != QLineF::NoIntersection)
 		{
 			QLineF rad1 = QLineF(center, pStart);
 			QLineF rad3 = QLineF(center, pInter);
@@ -1690,7 +1687,7 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QLineF n_i = s_i.normalVector();
 		n_i.translate(s_i.pointAt(0.5) - s_i.p1());
 		QPointF center;
-		if (n_s.intersect(n_i, &center) != QLineF::NoIntersection)
+		if (n_s.intersects(n_i, &center) != QLineF::NoIntersection)
 		{
 			QLineF rad1 = QLineF(center, pStart);
 			QLineF rad3 = QLineF(center, pInter);
@@ -1930,7 +1927,7 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			for (int a = 0; a < elPo.size() - 1; a++)
 			{
 				QPointF intersect;
-				if (QLineF(elPo[a], elPo[a+1]).intersect(stv, &intersect) == QLineF::BoundedIntersection)
+				if (QLineF(elPo[a], elPo[a+1]).intersects(stv, &intersect) == QLineF::BoundedIntersection)
 				{
 					stP = intersect;
 					break;
@@ -1939,7 +1936,7 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			for (int a = 0; a < elPo.size() - 1; a++)
 			{
 				QPointF intersect;
-				if (QLineF(elPo[a], elPo[a+1]).intersect(env, &intersect) == QLineF::BoundedIntersection)
+				if (QLineF(elPo[a], elPo[a+1]).intersects(env, &intersect) == QLineF::BoundedIntersection)
 				{
 					enP = intersect;
 					break;
@@ -2027,7 +2024,7 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		for (int a = 0; a < elPo.size() - 1; a++)
 		{
 			QPointF intersect;
-			if (QLineF(elPo[a], elPo[a+1]).intersect(stv, &intersect) == QLineF::BoundedIntersection)
+			if (QLineF(elPo[a], elPo[a+1]).intersects(stv, &intersect) == QLineF::BoundedIntersection)
 			{
 				stP = intersect;
 				break;
@@ -2037,7 +2034,7 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		for (int a = 0; a < elPo.size() - 1; a++)
 		{
 			QPointF intersect;
-			if (QLineF(elPo[a], elPo[a+1]).intersect(env, &intersect) == QLineF::BoundedIntersection)
+			if (QLineF(elPo[a], elPo[a+1]).intersects(env, &intersect) == QLineF::BoundedIntersection)
 			{
 				enP = intersect;
 				break;
@@ -2353,10 +2350,7 @@ void CgmPlug::decodeClass5(QDataStream &ts, quint16 elemID, quint16 paramLen)
 	{
 		quint16 data;
 		ts >> data;
-		if (data == 0)
-			lineVisible = false;
-		else
-			lineVisible = true;
+		lineVisible = data != 0;
  		// qDebug() << "EDGE VISIBILITY";
 	}
 	else if (elemID == 31)
