@@ -58,6 +58,7 @@ for which a new license (GPL+exception) is in place.
 #include "ui/scmwmenumanager.h"
 #include "units.h"
 
+#include "api/api_application.h"
 
 #include <QApplication>
 #include <QMessageBox>
@@ -90,12 +91,12 @@ PyObject* wrappedQApp;
 ScripterCore* scripterCore;
 
 
-int scriptplugin_getPluginAPIVersion()
+int scriptplugin_py2x_getPluginAPIVersion()
 {
 	return PLUGIN_API_VERSION;
 }
 
-ScPlugin* scriptplugin_getPlugin()
+ScPlugin* scriptplugin_py2x_getPlugin()
 {
 	scripterCore=nullptr;
 	ScriptPlugin* plug = new ScriptPlugin();
@@ -103,7 +104,7 @@ ScPlugin* scriptplugin_getPlugin()
 	return plug;
 }
 
-void scriptplugin_freePlugin(ScPlugin* plugin)
+void scriptplugin_py2x_freePlugin(ScPlugin* plugin)
 {
 	ScriptPlugin* plug = qobject_cast<ScriptPlugin*>(plugin);
 	Q_ASSERT(plug);
@@ -133,7 +134,7 @@ void ScriptPlugin::addToMainWindowMenu(ScribusMainWindow* mw)
 
 QString ScriptPlugin::fullTrName() const
 {
-	return QObject::tr("Scripter");
+	return QObject::tr("Scripter for Python 2.x");
 }
 
 const ScActionPlugin::AboutData* ScriptPlugin::getAboutData() const
@@ -146,7 +147,6 @@ const ScActionPlugin::AboutData* ScriptPlugin::getAboutData() const
 			"Craig Ringer <craig@scribus.info>");
 	about->shortDescription = tr("Embedded Python scripting support for Python 2.x.");
 	// about->description = tr("Write me!")
-	// about->version
 	// about->releaseDate
 	// about->copyright
 	// about->license
@@ -225,7 +225,7 @@ void run()
 /*                                                                                      */
 /****************************************************************************************/
 
-/*static */PyObject *scribus_retval(PyObject* /*self*/, PyObject* args)
+/*static */PyObject *scribus_py2x_retval(PyObject* /*self*/, PyObject* args)
 {
 	char *Name = nullptr;
 	if (!PyArg_ParseTuple(args, (char*) "s", &Name))
@@ -239,7 +239,7 @@ void run()
 	return PyInt_FromLong(0L);
 }
 
-/*static */PyObject *scribus_getval(PyObject* /*self*/)
+/*static */PyObject *scribus_py2x_getval(PyObject* /*self*/)
 {
 	return PyString_FromString(scripterCore->inValue.toUtf8().data());
 }
@@ -606,8 +606,8 @@ PyMethodDef scribus_methods[] = {
 	// by Tj (hacker@iam.tj>
 	{const_cast<char*>("combinePolygons"), (PyCFunction)scribus_combinepolygons, METH_NOARGS, tr(scribus_combinepolygons__doc__)},
 	// Internal methods - Not for public use
-	{const_cast<char*>("retval"), (PyCFunction)scribus_retval, METH_VARARGS, const_cast<char*>("Scribus internal.")},
-	{const_cast<char*>("getval"), (PyCFunction)scribus_getval, METH_NOARGS, const_cast<char*>("Scribus internal.")},
+	{const_cast<char*>("retval"), (PyCFunction)scribus_py2x_retval, METH_VARARGS, const_cast<char*>("Scribus internal.")},
+	{const_cast<char*>("getval"), (PyCFunction)scribus_py2x_getval, METH_NOARGS, const_cast<char*>("Scribus internal.")},
 	{const_cast<char*>("setLinkAnnotation"), scribus_setlinkannotation, METH_VARARGS,tr(scribus_setlinkannotation__doc__)},
 	{const_cast<char*>("setFileAnnotation"), (PyCFunction)scribus_setfileannotation, METH_VARARGS|METH_KEYWORDS,tr(scribus_setfileannotation__doc__)},
 	{const_cast<char*>("setURIAnnotation"), scribus_seturiannotation, METH_VARARGS,tr(scribus_seturiannotation__doc__)},
@@ -895,28 +895,18 @@ void initscribus(ScribusMainWindow *mainWin)
 	}
 
 	// Export the Scribus version into the module namespace so scripts know what they're running in
-	PyDict_SetItemString(d, const_cast<char*>("scribus_version"), PyString_FromString(const_cast<char*>(VERSION)));
+	PyDict_SetItemString(d, const_cast<char*>("scribus_version"), PyString_FromString(ScribusAPI::getVersion().toLatin1().constData()));
 	// Now build a version tuple like that provided by Python in sys.version_info
 	// The tuple is of the form (major, minor, patchlevel, extraversion, reserved)
-	QRegExp version_re("(\\d+)\\.(\\d+)\\.(\\d+)(.*)");
-	int pos = version_re.indexIn(QString(VERSION));
-	// We ignore errors, causing the scribus_version_info attribute to simply not be created.
-	// This will make acceses raise AttrbuteError.
-	if (pos > -1)
-	{
-		int majorVersion = version_re.cap(1).toInt();
-		int minorVersion = version_re.cap(2).toInt();
-		int patchVersion = version_re.cap(3).toInt();
-		QString extraVersion = version_re.cap(4);
-		PyObject* versionTuple = Py_BuildValue(const_cast<char*>("(iiisi)"),\
-				majorVersion, minorVersion, patchVersion, (const char*)extraVersion.toUtf8(), 0);
-		if (versionTuple != nullptr)
-			PyDict_SetItemString(d, const_cast<char*>("scribus_version_info"), versionTuple);
-		else
-			qDebug("Failed to build version tuple for version string '%s' in scripter", VERSION);
-	}
+	int majorVersion = ScribusAPI::getVersionMajor();
+	int minorVersion = ScribusAPI::getVersionMinor();
+	int patchVersion = ScribusAPI::getVersionPatch();
+	QString extraVersion = ScribusAPI::getVersionSuffix();
+	PyObject* versionTuple = Py_BuildValue(const_cast<char*>("(iiisi)"), majorVersion, minorVersion, patchVersion, (const char*)extraVersion.toUtf8(), 0);
+	if (versionTuple != nullptr)
+		PyDict_SetItemString(d, const_cast<char*>("scribus_version_info"), versionTuple);
 	else
-		qDebug("Couldn't parse version string '%s' in scripter", VERSION);
+		qDebug()<<"Failed to build version tuple for version string "<< ScribusAPI::getVersion() << " in scripter";
 
 	// Function aliases for compatibility
 	// We need to import the __builtins__, warnings and exceptions modules to be able to run
