@@ -141,12 +141,7 @@ void ScPageOutput::drawMasterItems(ScPainterExBase *painter, ScPage *page, ScLay
 		}
 		QRectF oldR(currItem->getBoundingRect().adjusted(0.0, 0.0, 1.0, 1.0));
 		if (clip.intersects(oldR.toRect()))
-		{
-			// relayout necessary to get page number ok
-			currItem->invalidateLayout();
-			currItem->layout();
 			drawItem(currItem, painter, clip);
-		}
 		currItem->OwnPage = savedOwnPage;
 		if (!currItem->ChangedMasterItem)
 		{
@@ -723,10 +718,13 @@ void ScPageOutput::drawItem_Group(PageItem_Group* item, ScPainterExBase* painter
 		PageItem* embedded = item->groupItemList.at(em);
 		painter->save();
 		painter->translate(embedded->gXpos, embedded->gYpos);
+		embedded->savedOwnPage = embedded->OwnPage;
+		embedded->OwnPage = item->OwnPage;
 		embedded->isEmbedded = true;
 		embedded->invalidateLayout();
 		drawItem(embedded, painter, QRect());
 		embedded->isEmbedded = false;
+		embedded->OwnPage = embedded->savedOwnPage;
 		painter->restore();
 	}
 	//painter->endLayer();
@@ -982,7 +980,7 @@ public:
 		int fm = m_painter->fillMode();
 
 		m_painter->setFillRule(false);
-		m_painter->setFillMode(1);
+		m_painter->setFillMode(ScPainterExBase::Solid);
 
 		setupState();
 
@@ -1059,8 +1057,8 @@ public:
 	{
 		m_painter->save();
 		setupState();
-		m_painter->setFillMode(1);
-		m_painter->setStrokeMode(1);
+		m_painter->setFillMode(ScPainterExBase::Solid);
+		m_painter->setStrokeMode(ScPainterExBase::Solid);
 		m_painter->drawRect(rect.x(), rect.y(), rect.width(), rect.height());
 		m_painter->restore();
 	}
@@ -1507,6 +1505,13 @@ void ScPageOutput::drawItem_Text(PageItem* item, ScPainterExBase* painter, QRect
 		painter->restore();
 	}
 
+	if (item->isMasterItem())
+	{
+		// relayout necessary to get page number ok
+		item->invalidateLayout();
+		item->layout();
+	}
+
 	ScPageOutputPainter p(item, painter, this);
 	item->textLayout.renderBackground(&p);
 	item->textLayout.render(&p);
@@ -1610,7 +1615,7 @@ void ScPageOutput::drawMarks(ScPage* page, ScPainterExBase* painter, const Marks
 	{
 		FPoint start, end;
 		double left = offsetX - bleedLeft, right = offsetX + width + bleedRight;
-		double bottom = offsetY + height + bleedBottom, top = offsetY - bleedTop;;
+		double bottom = offsetY + height + bleedBottom, top = offsetY - bleedTop;
 		drawBoxMarks(painter, QRectF(QPointF(left, top), QPointF(right, bottom)), bleedBox, markOffs, markLength);
 	}
 	if (options.registrationMarks)
