@@ -107,6 +107,7 @@ public:
 	bool isLoading() const;
 	void setModified(bool);
 	bool isModified() const;
+	bool isUndoRedoOngoing() const;
 /** Setzt die Seitenattribute */
 	void setPage(double w, double h, double t, double l, double r, double b, double sp, double ab, bool atf, int fp);
 
@@ -168,39 +169,50 @@ public:
 	void setAutoSaveDir(const QString& autoDaveDir) { m_docPrefsData.docSetupPrefs.AutoSaveDir = autoDaveDir; }
 	//FIXME (maybe) :non const, the loaders make a mess here
 	PDFOptions& pdfOptions() { return m_docPrefsData.pdfPrefs; }
+
 	ObjAttrVector& itemAttributes() { return m_docPrefsData.itemAttrPrefs.defaultItemAttributes; }
 	void setItemAttributes(ObjAttrVector& oav) { m_docPrefsData.itemAttrPrefs.defaultItemAttributes=oav;}
 	void clearItemAttributes() { m_docPrefsData.itemAttrPrefs.defaultItemAttributes.clear(); }
 	void appendToItemAttributes(const ObjectAttribute& oa) { m_docPrefsData.itemAttrPrefs.defaultItemAttributes.append(oa); }
+
 	ToCSetupVector& tocSetups() { return m_docPrefsData.tocPrefs.defaultToCSetups; }
 	void setTocSetups(ToCSetupVector& tsv) { m_docPrefsData.tocPrefs.defaultToCSetups=tsv; }
 	void clearTocSetups() { m_docPrefsData.tocPrefs.defaultToCSetups.clear(); }
 	void appendToTocSetups(const ToCSetup& ts) { m_docPrefsData.tocPrefs.defaultToCSetups.append(ts); }
-	void setArrowStyles(QList<ArrowDesc>& as) { m_docPrefsData.arrowStyles=as; }
+
+	void setArrowStyles(QList<ArrowDesc>& as) { m_docPrefsData.arrowStyles = as; }
 	QList<ArrowDesc>& arrowStyles() { return m_docPrefsData.arrowStyles; }
+	ArrowDesc* arrowStyle(const QString& name);
+	bool hasArrowStyle(const QString& name) const;
 	void appendToArrowStyles(const struct ArrowDesc& as) { m_docPrefsData.arrowStyles.append(as); }
+
 	bool marginColored() const { return m_docPrefsData.displayPrefs.marginColored; }
-	void setMarginColored(bool b) { m_docPrefsData.displayPrefs.marginColored=b; }
+	void setMarginColored(bool b) { m_docPrefsData.displayPrefs.marginColored = b; }
+
 	QMap<QString, CheckerPrefs>& checkerProfiles() { return m_docPrefsData.verifierPrefs.checkerPrefsList; }
-	void setCheckerProfiles(const QMap<QString, CheckerPrefs>& cl) { m_docPrefsData.verifierPrefs.checkerPrefsList=cl; }
+	void setCheckerProfiles(const QMap<QString, CheckerPrefs>& cl) { m_docPrefsData.verifierPrefs.checkerPrefsList = cl; }
 	void set1CheckerProfile(const QString& profileName, const struct CheckerPrefs& cs) { m_docPrefsData.verifierPrefs.checkerPrefsList[profileName] = cs; }
 	void clearCheckerProfiles() { m_docPrefsData.verifierPrefs.checkerPrefsList.clear(); }
 	const QString& curCheckProfile() const { return m_docPrefsData.verifierPrefs.curCheckProfile; }
-	void setCurCheckProfile(const QString& s) { m_docPrefsData.verifierPrefs.curCheckProfile=s; }
+	void setCurCheckProfile(const QString& s) { m_docPrefsData.verifierPrefs.curCheckProfile = s; }
+
 	const QString& language() const { return m_docPrefsData.docSetupPrefs.language; }
-	void setLanguage(const QString& s) { m_docPrefsData.docSetupPrefs.language=s; }
+	void setLanguage(const QString& s) { m_docPrefsData.docSetupPrefs.language = s; }
+
 	int pageOrientation() const { return m_docPrefsData.docSetupPrefs.pageOrientation; }
-	void setPageOrientation(int o) { m_docPrefsData.docSetupPrefs.pageOrientation=o; }
+	void setPageOrientation(int o) { m_docPrefsData.docSetupPrefs.pageOrientation = o; }
 	int pagePositioning() const { return m_docPrefsData.docSetupPrefs.pagePositioning; }
-	void setPagePositioning(int p) { m_docPrefsData.docSetupPrefs.pagePositioning=p; }
+	void setPagePositioning(int p) { m_docPrefsData.docSetupPrefs.pagePositioning = p; }
+
 	double pageHeight() const { return m_docPrefsData.docSetupPrefs.pageHeight; }
 	double pageWidth() const { return m_docPrefsData.docSetupPrefs.pageWidth; }
 	const QString& pageSize() const { return m_docPrefsData.docSetupPrefs.pageSize; }
-	void setPageHeight(double h) { m_docPrefsData.docSetupPrefs.pageHeight=h; }
-	void setPageWidth(double w) { m_docPrefsData.docSetupPrefs.pageWidth=w; }
-	void setPageSize(const QString& s) { m_docPrefsData.docSetupPrefs.pageSize=s; }
+	void setPageHeight(double h) { m_docPrefsData.docSetupPrefs.pageHeight = h; }
+	void setPageWidth(double w) { m_docPrefsData.docSetupPrefs.pageWidth = w; }
+	void setPageSize(const QString& s) { m_docPrefsData.docSetupPrefs.pageSize = s; }
+
 	int marginPreset() const { return m_docPrefsData.docSetupPrefs.marginPreset; }
-	void setMarginPreset(int mp) { m_docPrefsData.docSetupPrefs.marginPreset=mp; }
+	void setMarginPreset(int mp) { m_docPrefsData.docSetupPrefs.marginPreset = mp; }
 
 	TypoPrefs& typographicPrefs() { return m_docPrefsData.typoPrefs; }
 	GuidesPrefs& guidesPrefs() { return m_docPrefsData.guidesPrefs; }
@@ -209,9 +221,9 @@ public:
 	ColorPrefs& colorPrefs() { return m_docPrefsData.colorPrefs; }
 	CMSData& cmsSettings() { return m_docPrefsData.colorPrefs.DCMSset; }
 	DocumentInformation& documentInfo() { return m_docPrefsData.docInfo; }
-	void setDocumentInfo(DocumentInformation di) { m_docPrefsData.docInfo=di; }
+	void setDocumentInfo(DocumentInformation di) { m_docPrefsData.docInfo = di; }
 	DocumentSectionMap& sections() { return m_docPrefsData.docSectionMap; }
-	void setSections(DocumentSectionMap dsm) { m_docPrefsData.docSectionMap=std::move(dsm); }
+	void setSections(DocumentSectionMap dsm) { m_docPrefsData.docSectionMap = std::move(dsm); }
 	const QMap<QString, int> & usedFonts() { return UsedFonts; }
 
 	const ApplicationPrefs& prefsData() { return m_docPrefsData; }
@@ -601,7 +613,9 @@ public:
 		ResourceCollection m_newNames;
 	};
 	void replaceNamedResources(ResourceCollection& newNames);
-	bool styleExists(const QString& styleName);
+	
+	bool styleExists(const QString& styleName) const;
+	bool charStyleExists(const QString& styleName) const;
 	
 	QList<int> getSortedStyleList();
 	QList<int> getSortedCharStyleList();
@@ -672,8 +686,8 @@ public:
 	/*!
 	 * @brief Returns a qmap of the fonts and  their glyphs used within the document
 	 */
-	void getUsedFonts(QMap<QString,QMap<uint, FPointArray> > &Really);
-	void checkItemForFonts(PageItem *it, QMap<QString, QMap<uint, FPointArray> > & Really, uint lc);
+	void getUsedFonts(QMap<QString,QMap<uint, QString> > &Really);
+	void checkItemForFonts(PageItem *it, QMap<QString, QMap<uint, QString> > & Really, uint lc);
 
 	/*!
 	 * @brief Replace line style colors
@@ -1076,7 +1090,7 @@ public:
 	PageItem* groupObjectsSelection(Selection* customSelection = nullptr);
 	PageItem* groupObjectsList(QList<PageItem*> &itemList);
 	void groupObjectsToItem(PageItem* groupItem, QList<PageItem*> &itemList);
-	PageItem * itemSelection_GroupObjects  (bool changeLock, bool lock, Selection* customSelection = nullptr);
+	PageItem * itemSelection_GroupObjects  (bool changeLock, bool lock, Selection* customSelection = nullptr, PageItem_Group* groupItem = nullptr);
 	void itemSelection_UnGroupObjects(Selection* customSelection = nullptr);
 	void addToGroup(PageItem* group, PageItem* item);
 	void removeFromGroup(PageItem* item);
@@ -1272,6 +1286,7 @@ protected:
 	UndoManager * const m_undoManager;
 	bool m_loading {false};
 	bool m_modified {false};
+	int  m_undoRedoOngoing {0};
 	int m_ActiveLayer {0};
 	double m_docUnitRatio;
 	int m_rotMode {0};
@@ -1358,11 +1373,13 @@ public: // Public attributes
 	PageItem *DraggedElem {nullptr};
 	PageItem *ElemToLink {nullptr};
 	QList<PageItem*> DragElements;
+
 private:
 	StyleSet<ParagraphStyle> m_docParagraphStyles;
 	StyleSet<CharStyle> m_docCharStyles;
 	StyleSet<TableStyle> m_docTableStyles;
 	StyleSet<CellStyle> m_docCellStyles;
+
 public:
 	ScLayers Layers;
 	//bool marginColored;
@@ -1554,7 +1571,8 @@ public slots:
 	void itemSelection_DistributeTop();
 	void itemSelection_SwapLeft();
 	void itemSelection_SwapRight();
-	void itemSelection_MultipleDuplicate(const ItemMultipleDuplicateData&);
+	void itemSelection_Duplicate(double shiftX, double shiftY, Selection* customSelection = nullptr);
+	void itemSelection_MultipleDuplicate(const ItemMultipleDuplicateData&, Selection* customSelection = nullptr);
 	void itemSelection_UniteItems(Selection* customSelection = nullptr);
 	void itemSelection_SplitItems(Selection* customSelection = nullptr);
 	/**
