@@ -715,7 +715,7 @@ void ColorPalette::updateGradientList()
 		pb.end();
 		ScPainter *p = new ScPainter(&pixm, 48, 12);
 		p->setPen(Qt::black, 1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-		p->setFillMode(2);
+		p->setFillMode(ScPainter::Gradient);
 		p->fill_gradient = gr;
 		p->setGradient(VGradient::linear, FPoint(0,6), FPoint(48, 6), FPoint(0,0), 1, 0);
 		p->drawRect(0, 0, 48, 12);
