@@ -117,26 +117,29 @@ FontComboH::FontComboH(QWidget* parent, bool labels) :
 	psFont = IconManager::instance().loadPixmap("font_type1_16.png");
 	substFont = IconManager::instance().loadPixmap("font_subst16.png");
 	fontComboLayout = new QGridLayout(this);
-	fontComboLayout->setMargin(0);
-	fontComboLayout->setSpacing(0);
-	int col=0;
+	fontComboLayout->setContentsMargins(0, 0, 0, 0);
+	if (showLabels)
+		fontComboLayout->setSpacing(6);
+	else
+		fontComboLayout->setSpacing(3);
+	int col = 0;
 	if (showLabels)
 	{
-		fontFaceLabel=new QLabel("", this);
-		fontStyleLabel=new QLabel("", this);
-		fontComboLayout->addWidget(fontFaceLabel,0,0);
-		fontComboLayout->addWidget(fontStyleLabel,1,0);
-		fontComboLayout->setColumnStretch(1,10);
-		col=1;
+		fontFaceLabel = new QLabel(this);
+		fontStyleLabel = new QLabel(this);
+		fontComboLayout->addWidget(fontFaceLabel, 0, 0);
+		fontComboLayout->addWidget(fontStyleLabel, 1, 0);
+		fontComboLayout->setColumnStretch(1, 10);
+		col = 1;
 	}
 	fontFamily = new QComboBox(this);
 	fontFamily->setEditable(true);
 	fontFamily->setValidator(new FontComboValidator(fontFamily));
 	fontFamily->setInsertPolicy(QComboBox::NoInsert);
 	fontFamily->setItemDelegate(new FontFamilyDelegate(this));
-	fontComboLayout->addWidget(fontFamily,0,col);
+	fontComboLayout->addWidget(fontFamily, 0, col);
 	fontStyle = new QComboBox(this);
-	fontComboLayout->addWidget(fontStyle,1,col);
+	fontComboLayout->addWidget(fontStyle, 1, col);
 	isForAnnotation = true;  // this is merely to ensure that the list is rebuilt
 	rebuildList(nullptr);
 	connect(fontFamily, SIGNAL(activated(int)), this, SLOT(familySelected(int)));
@@ -184,12 +187,10 @@ void FontComboH::familySelected(int id)
 	fontStyle->addItems(slist);
 	if (slist.contains(curr))
 		setCurrentComboItem(fontStyle, curr);
-	else
-		if (slist.contains("Regular"))
-			setCurrentComboItem(fontStyle, "Regular");
-		else
-			if (slist.contains("Roman"))
-				setCurrentComboItem(fontStyle, "Roman");
+	else if (slist.contains("Regular"))
+		setCurrentComboItem(fontStyle, "Regular");
+	else if (slist.contains("Roman"))
+		setCurrentComboItem(fontStyle, "Roman");
 	emit fontSelected(fontFamily->itemText(id) + " " + fontStyle->currentText());
 	connect(fontStyle, SIGNAL(activated(int)), this, SLOT(styleSelected(int)));
 }
@@ -501,8 +502,11 @@ FontFamilyDelegate::FontFamilyDelegate(QObject *parent)
 
 void FontFamilyDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
+	double pixelRatio = painter->device()->devicePixelRatioF();
+	int pixmapW = qRound(pixelRatio * option.rect.width());
+	int pixmapH = qRound(pixelRatio * option.rect.height());
 	QString text(index.data(Qt::DisplayRole).toString());
-	QString wh=QString("-w%1h%2").arg(option.rect.width()).arg(option.rect.height());
+	QString wh = QString("-w%1h%2").arg(pixmapW).arg(pixmapH);
 	QPixmap cachedPixmap;
 	QString cacheKey = text + wh;
 	if (option.state & QStyle::State_Selected)
@@ -516,8 +520,11 @@ void FontFamilyDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
 	QFontDatabase& fontDb = ScQApp->qtFontDatabase();
 	const ScFace& scFace = getScFace(this->parent()->metaObject()->className(), text);
 
-	QPixmap  pixmap(option.rect.width(), option.rect.height());
-	QPixmap  invPixmap(option.rect.width(), option.rect.height());
+	QPixmap  pixmap(pixmapW, pixmapH);
+	QPixmap  invPixmap(pixmapW, pixmapH);
+	pixmap.setDevicePixelRatio(pixelRatio);
+	invPixmap.setDevicePixelRatio(pixelRatio);
+
 	QPainter pixPainter(&pixmap);
 	QPainter invpixPainter(&invPixmap);
 
