@@ -13,6 +13,7 @@ for which a new license (GPL+exception) is in place.
 #include <QGroupBox>
 #include <QCheckBox>
 #include <QPushButton>
+#include <QScopedPointer>
 
 #include "commonstrings.h"
 #include "iconmanager.h"
@@ -24,59 +25,63 @@ for which a new license (GPL+exception) is in place.
 #include "util.h"
 
 InsPage::InsPage( QWidget* parent, ScribusDoc* currentDoc, int currentPage, int maxPages)
-	: QDialog( parent, Qt::WindowFlags() )
+	: QDialog(parent, Qt::WindowFlags())
 {
 	m_doc = currentDoc;
-
 	masterPageCombos.clear();
+
 	setModal(true);
 	setWindowTitle( tr( "Insert Page" ) );
 	setWindowIcon(IconManager::instance().loadIcon("AppIcon.png"));
+
 	dialogLayout = new QVBoxLayout(this);
-	dialogLayout->setSpacing( 5 );
-	dialogLayout->setMargin( 5 );
+	dialogLayout->setSpacing(6);
+	dialogLayout->setContentsMargins(9, 9, 9, 9);
+
 	whereLayout = new QGridLayout();
-	whereLayout->setSpacing( 5 );
-	whereLayout->setMargin( 5 );
-	insCountData = new QSpinBox( this );
+	whereLayout->setSpacing(6);
+	whereLayout->setContentsMargins(0, 0, 0, 0);
+
+	insCountData = new QSpinBox(this);
 	insCountData->setMinimum(1);
 	insCountData->setMaximum(999);
-	insCountData->setValue( 1 );
+	insCountData->setValue(1);
 	insCountLabel = new QLabel(tr( "&Insert" ), this );
 	insCountLabel->setBuddy(insCountData);
-	whereLayout->addWidget( insCountLabel, 0, 0 );
-	whereLayout->addWidget( insCountData, 0, 1 );
+	whereLayout->addWidget(insCountLabel, 0, 0);
+	whereLayout->addWidget(insCountData, 0, 1);
+
 	pagesLabel = new QLabel( tr( "Page(s)" ), this);
-	whereLayout->addWidget( pagesLabel, 0, 2 );
+	whereLayout->addWidget(pagesLabel, 0, 2);
 
 	insWhereData = new QComboBox( this );
 	insWhereData->addItem( tr("before Page"));
 	insWhereData->addItem( tr("after Page"));
 	insWhereData->addItem( tr("at End"));
 	insWhereData->setCurrentIndex(2);
-	whereLayout->addWidget( insWhereData, 1, 0, 1, 2 );
+	whereLayout->addWidget(insWhereData, 1, 0, 1, 2);
 
 	insWherePageData = new QSpinBox(this);
 	insWherePageData->setMinimum(1);
 	insWherePageData->setMaximum(maxPages);
-	insWherePageData->setValue( currentPage+1 );
-	insWherePageData->setDisabled( true );
+	insWherePageData->setValue(currentPage + 1);
+	insWherePageData->setDisabled(true);
 
-	whereLayout->addWidget( insWherePageData, 1, 2 );
+	whereLayout->addWidget(insWherePageData, 1, 2);
 	whereLayout->addItem(new QSpacerItem(insCountLabel->fontMetrics().horizontalAdvance( tr( "&Insert" )), 0), 0, 0);
-	dialogLayout->addLayout( whereLayout );
+	dialogLayout->addLayout(whereLayout);
 	
 	masterPageLabel = nullptr;
 	masterPageGroup = new QGroupBox( this);
 	masterPageGroup->setTitle( tr( "Master Pages" ) );
 	masterPageLayout = new QGridLayout( masterPageGroup );
-	masterPageLayout->setAlignment( Qt::AlignTop );
-	masterPageLayout->setSpacing( 5 );
-	masterPageLayout->setMargin( 5 );
+	masterPageLayout->setAlignment(Qt::AlignTop);
+	masterPageLayout->setSpacing(6);
+	masterPageLayout->setContentsMargins(9, 9, 9, 9);
 	if (m_doc->pagePositioning() == 0)
 	{
 		QComboBox* pageData = new QComboBox(masterPageGroup);
-		for (QMap<QString,int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
+		for (QMap<QString, int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
 		{
 			pageData->addItem(it.key() == CommonStrings::masterPageNormal ? CommonStrings::trMasterPageNormal : it.key(), it.key());
 		}
@@ -84,7 +89,7 @@ InsPage::InsPage( QWidget* parent, ScribusDoc* currentDoc, int currentPage, int
 			setCurrentComboItem(pageData, CommonStrings::trMasterPageNormal);
 		masterPageLabel = new QLabel(tr("&Master Page:"), masterPageGroup);
 		masterPageLabel->setBuddy(pageData);
-		masterPageLayout->addWidget( masterPageLabel, 0, 0 );
+		masterPageLayout->addWidget(masterPageLabel, 0, 0);
 		masterPageLayout->addWidget(pageData, 0, 1);
 		masterPageCombos.append(pageData);
 	}
@@ -95,12 +100,12 @@ InsPage::InsPage( QWidget* parent, ScribusDoc* currentDoc, int currentPage, int
 		for (int mp = 0; mp < currentPageSet.pageNames.count(); ++mp)
 		{
 			QComboBox* pageData = new QComboBox(masterPageGroup);
-//			for (QMap<QString,int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
+//			for (QMap<QString, int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
 //				pageData->insertItem(it.key() == CommonStrings::masterPageNormal ? CommonStrings::trMasterPageNormal : it.key());
 			if (mp == 0)
 			{
-				bool conNam = m_doc->MasterNames.contains( CommonStrings::trMasterPageNormalLeft);
-				for (QMap<QString,int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
+				bool conNam = m_doc->MasterNames.contains(CommonStrings::trMasterPageNormalLeft);
+				for (QMap<QString, int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
 				{
 					if ((it.key() == CommonStrings::masterPageNormal) && (!conNam))
 						pageData->addItem(CommonStrings::trMasterPageNormal, it.key());
@@ -112,7 +117,7 @@ InsPage::InsPage( QWidget* parent, ScribusDoc* currentDoc, int currentPage, int
 							pageData->addItem(it.key(), it.key());
 					}
 				}
-				if (m_doc->MasterNames.contains( CommonStrings::trMasterPageNormalLeft))
+				if (m_doc->MasterNames.contains(CommonStrings::trMasterPageNormalLeft))
 					setCurrentComboItem(pageData, CommonStrings::trMasterPageNormalLeft);
 			}
 			else if (mp == 1)
@@ -120,7 +125,7 @@ InsPage::InsPage( QWidget* parent, ScribusDoc* currentDoc, int currentPage, int
 				if (currentPageSet.pageNames.count() > 2)
 				{
 					bool conNam = m_doc->MasterNames.contains( CommonStrings::trMasterPageNormalMiddle);
-					for (QMap<QString,int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
+					for (QMap<QString, int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
 					{
 						if ((it.key() == CommonStrings::masterPageNormal) && (!conNam))
 							pageData->addItem(CommonStrings::trMasterPageNormal, it.key());
@@ -132,13 +137,13 @@ InsPage::InsPage( QWidget* parent, ScribusDoc* currentDoc, int currentPage, int
 								pageData->addItem(it.key(), it.key());
 						}
 					}
-					if (m_doc->MasterNames.contains( CommonStrings::trMasterPageNormalMiddle))
+					if (m_doc->MasterNames.contains(CommonStrings::trMasterPageNormalMiddle))
 						setCurrentComboItem(pageData, CommonStrings::trMasterPageNormalMiddle);
 				}
 				else
 				{
 					bool conNam = m_doc->MasterNames.contains( CommonStrings::trMasterPageNormalRight);
-					for (QMap<QString,int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
+					for (QMap<QString, int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
 					{
 						if ((it.key() == CommonStrings::masterPageNormal) && (!conNam))
 							pageData->addItem(CommonStrings::trMasterPageNormal, it.key());
@@ -150,7 +155,7 @@ InsPage::InsPage( QWidget* parent, ScribusDoc* currentDoc, int currentPage, int
 								pageData->addItem(it.key(), it.key());
 						}
 					}
-					if (m_doc->MasterNames.contains( CommonStrings::trMasterPageNormalRight))
+					if (m_doc->MasterNames.contains(CommonStrings::trMasterPageNormalRight))
 						setCurrentComboItem(pageData, CommonStrings::trMasterPageNormalRight);
 				}
 			}
@@ -158,8 +163,8 @@ InsPage::InsPage( QWidget* parent, ScribusDoc* currentDoc, int currentPage, int
 			{
 				if (currentPageSet.pageNames.count() > 3)
 				{
-					bool conNam = m_doc->MasterNames.contains( CommonStrings::trMasterPageNormalMiddle);
-					for (QMap<QString,int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
+					bool conNam = m_doc->MasterNames.contains(CommonStrings::trMasterPageNormalMiddle);
+					for (QMap<QString, int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
 					{
 						if ((it.key() == CommonStrings::masterPageNormal) && (!conNam))
 							pageData->addItem(CommonStrings::trMasterPageNormal, it.key());
@@ -171,13 +176,13 @@ InsPage::InsPage( QWidget* parent, ScribusDoc* currentDoc, int currentPage, int
 								pageData->addItem(it.key(), it.key());
 						}
 					}
-					if (m_doc->MasterNames.contains( CommonStrings::trMasterPageNormalMiddle))
+					if (m_doc->MasterNames.contains(CommonStrings::trMasterPageNormalMiddle))
 						setCurrentComboItem(pageData, CommonStrings::trMasterPageNormalMiddle);
 				}
 				else
 				{
-					bool conNam = m_doc->MasterNames.contains( CommonStrings::trMasterPageNormalRight);
-					for (QMap<QString,int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
+					bool conNam = m_doc->MasterNames.contains(CommonStrings::trMasterPageNormalRight);
+					for (QMap<QString, int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
 					{
 						if ((it.key() == CommonStrings::masterPageNormal) && (!conNam))
 							pageData->addItem(CommonStrings::trMasterPageNormal, it.key());
@@ -196,7 +201,7 @@ InsPage::InsPage( QWidget* parent, ScribusDoc* currentDoc, int currentPage, int
 			else if (mp == 3)
 			{
 				bool conNam = m_doc->MasterNames.contains( CommonStrings::trMasterPageNormalRight);
-				for (QMap<QString,int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
+				for (QMap<QString, int>::Iterator it = m_doc->MasterNames.begin(); it != m_doc->MasterNames.end(); ++it)
 				{
 					if ((it.key() == CommonStrings::masterPageNormal) && (!conNam))
 						pageData->addItem(CommonStrings::trMasterPageNormal, it.key());
@@ -221,77 +226,82 @@ InsPage::InsPage( QWidget* parent, ScribusDoc* currentDoc, int currentPage, int
 		}
 	}
 	dialogLayout->addWidget(masterPageGroup);
-	overrideMPSizingCheckBox=new QCheckBox( tr("Override Master Page Sizing"));
+	overrideMPSizingCheckBox = new QCheckBox( tr("Override Master Page Sizing"));
 	dialogLayout->addWidget(overrideMPSizingCheckBox);
 	dsGroupBox7 = new QGroupBox( this );
 	dsGroupBox7->setTitle( tr( "Page Size" ) );
-	dsGroupBox7Layout = new QGridLayout( dsGroupBox7 );
-	dsGroupBox7Layout->setSpacing( 5 );
-	dsGroupBox7Layout->setMargin( 5 );
-	TextLabel1 = new QLabel( tr( "&Size:" ), dsGroupBox7);
-	dsGroupBox7Layout->addWidget( TextLabel1, 0, 0);
+	dsGroupBox7Layout = new QGridLayout(dsGroupBox7);
+	dsGroupBox7Layout->setSpacing(6);
+	dsGroupBox7Layout->setContentsMargins(9, 9, 9, 9);
+	textLabel1 = new QLabel( tr( "&Size:" ), dsGroupBox7);
+	dsGroupBox7Layout->addWidget(textLabel1, 0, 0);
 
-	PageSize *ps = new PageSize(m_doc->pageSize());
+	QScopedPointer<PageSize> ps(new PageSize(m_doc->pageSize()));
 	prefsPageSizeName = ps->name();
 	sizeQComboBox = new QComboBox(dsGroupBox7);
 	QStringList insertList(ps->activeSizeTRList());
-	if (insertList.indexOf(prefsPageSizeName)==-1)
-		insertList<<prefsPageSizeName;
+	if (insertList.indexOf(prefsPageSizeName) == -1)
+		insertList << prefsPageSizeName;
 	insertList.sort();
-	insertList<<CommonStrings::trCustomPageSize;
+	insertList << CommonStrings::trCustomPageSize;
 	sizeQComboBox->addItems(insertList);
 	int sizeIndex = insertList.indexOf(ps->nameTR());
 	if (sizeIndex != -1)
 		sizeQComboBox->setCurrentIndex(sizeIndex);
 	else
-		sizeQComboBox->setCurrentIndex(sizeQComboBox->count()-1);
+		sizeQComboBox->setCurrentIndex(sizeQComboBox->count() - 1);
 
-	TextLabel1->setBuddy(sizeQComboBox);
+	textLabel1->setBuddy(sizeQComboBox);
 	dsGroupBox7Layout->addWidget(sizeQComboBox, 0, 1, 1, 3);
-	TextLabel2 = new QLabel( tr( "Orie&ntation:" ), dsGroupBox7);
-	dsGroupBox7Layout->addWidget( TextLabel2, 1, 0);
+
+	textLabel2 = new QLabel( tr( "Orie&ntation:" ), dsGroupBox7);
+	dsGroupBox7Layout->addWidget(textLabel2, 1, 0);
+
 	orientationQComboBox = new QComboBox(dsGroupBox7);
 	orientationQComboBox->addItem( tr( "Portrait" ) );
 	orientationQComboBox->addItem( tr( "Landscape" ) );
 	orientationQComboBox->setCurrentIndex(m_doc->pageOrientation() );
-	TextLabel2->setBuddy(orientationQComboBox);
-	dsGroupBox7Layout->addWidget( orientationQComboBox, 1, 1, 1, 3 );
-	widthSpinBox = new ScrSpinBox( 1, 10000, dsGroupBox7, m_doc->unitIndex() );
+	textLabel2->setBuddy(orientationQComboBox);
+	dsGroupBox7Layout->addWidget(orientationQComboBox, 1, 1, 1, 3);
+
+	widthSpinBox = new ScrSpinBox(1, 10000, dsGroupBox7, m_doc->unitIndex());
 	widthQLabel = new QLabel( tr( "&Width:" ), dsGroupBox7);
 	widthSpinBox->setValue(m_doc->pageWidth() * m_doc->unitRatio());
 	widthQLabel->setBuddy(widthSpinBox);
-	dsGroupBox7Layout->addWidget( widthQLabel, 2, 0 );
-	dsGroupBox7Layout->addWidget( widthSpinBox, 2, 1 );
-	heightSpinBox = new ScrSpinBox( 1, 10000, dsGroupBox7, m_doc->unitIndex() );
+	dsGroupBox7Layout->addWidget(widthQLabel, 2, 0);
+	dsGroupBox7Layout->addWidget(widthSpinBox, 2, 1);
+
+	heightSpinBox = new ScrSpinBox(1, 10000, dsGroupBox7, m_doc->unitIndex());
 	heightSpinBox->setValue(m_doc->pageHeight() * m_doc->unitRatio());
 	heightQLabel = new QLabel( tr( "&Height:" ), dsGroupBox7);
 	heightQLabel->setBuddy(heightSpinBox);
-	dsGroupBox7Layout->addWidget( heightQLabel, 2, 2 );
-	dsGroupBox7Layout->addWidget( heightSpinBox, 2, 3 );
+	dsGroupBox7Layout->addWidget(heightQLabel, 3, 0);
+	dsGroupBox7Layout->addWidget(heightSpinBox, 3, 1);
+
 	moveObjectsCheckBox = new QCheckBox( dsGroupBox7);
 	moveObjectsCheckBox->setText( tr( "Move Objects with their Page" ) );
-	moveObjectsCheckBox->setChecked( true );
-	dsGroupBox7Layout->addWidget( moveObjectsCheckBox, 3, 0, 1, 4 );
-	dialogLayout->addWidget( dsGroupBox7 );
+	moveObjectsCheckBox->setChecked(true);
+	dsGroupBox7Layout->addWidget(moveObjectsCheckBox, 4, 0, 1, 4);
+	dialogLayout->addWidget(dsGroupBox7);
+
 	dsGroupBox7->setEnabled(false);
 	bool b = (sizeQComboBox->currentText() == CommonStrings::trCustomPageSize);
-	heightSpinBox->setEnabled( b );
-	widthSpinBox->setEnabled( b );
-	delete ps;
+	heightSpinBox->setEnabled(b);
+	widthSpinBox->setEnabled(b);
 
 	okCancelLayout = new QHBoxLayout;
-	okCancelLayout->setSpacing( 5 );
-	okCancelLayout->setMargin( 5 );
-	QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
-	okCancelLayout->addItem( spacer );
+	okCancelLayout->setSpacing(6);
+	okCancelLayout->setContentsMargins(0, 0, 0, 0);
+	QSpacerItem* spacer = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
+	okCancelLayout->addItem(spacer);
 
-	okButton = new QPushButton( CommonStrings::tr_OK, this);
-	okButton->setDefault( true );
-	okCancelLayout->addWidget( okButton );
+	okButton = new QPushButton(CommonStrings::tr_OK, this);
+	okButton->setDefault(true);
+	okCancelLayout->addWidget(okButton);
 
-	cancelButton = new QPushButton( CommonStrings::tr_Cancel, this);
-	okCancelLayout->addWidget( cancelButton );
-	dialogLayout->addLayout( okCancelLayout );
+	cancelButton = new QPushButton(CommonStrings::tr_Cancel, this);
+	okCancelLayout->addWidget(cancelButton);
+	dialogLayout->addLayout(okCancelLayout);
 	setMaximumSize(sizeHint());
 	m_unitRatio = m_doc->unitRatio();
 
