@@ -23,7 +23,18 @@ Prefs_ItemTools::Prefs_ItemTools(QWidget* parent, ScribusDoc* doc)
 	showFontPreview(false)
 {
 	setupUi(this);
-	lineEndArrowComboBox->setStartDirection(false);
+
+	scrollArea->viewport()->setAutoFillBackground(false);
+	scrollArea->widget()->setAutoFillBackground(false);
+	scrollArea_2->viewport()->setAutoFillBackground(false);
+	scrollArea_2->widget()->setAutoFillBackground(false);
+
+	languageChange();
+
+	m_caption = tr("Item Tools");
+	m_icon = "tools_16.png";
+
+	lineEndArrowComboBox->setArrowDirection(ArrowDirection::EndArrow);
 	shapeLineWidthSpinBox->setNewUnit(0);
 	shapeLineWidthSpinBox->setMaximum(36);
 	shapeLineWidthSpinBox->setDecimals(1);
@@ -46,12 +57,9 @@ Prefs_ItemTools::Prefs_ItemTools(QWidget* parent, ScribusDoc* doc)
 	textSizeSpinBox->setNewUnit(0);
 	textSizeSpinBox->setMinimum(0.5);
 	textSizeSpinBox->setMaximum(2048);
-	languageChange();
 }
 
-Prefs_ItemTools::~Prefs_ItemTools()
-{
-}
+Prefs_ItemTools::~Prefs_ItemTools() = default;
 
 
 void Prefs_ItemTools::languageChange()
@@ -133,6 +141,7 @@ void Prefs_ItemTools::restoreDefaults(struct ApplicationPrefs *prefsData)
 	bottomTextDistanceSpinBox->setValue(prefsData->itemToolPrefs.textDistances.bottom() * unitRatio);
 	leftTextDistanceSpinBox->setValue(prefsData->itemToolPrefs.textDistances.left() * unitRatio);
 	rightTextDistanceSpinBox->setValue(prefsData->itemToolPrefs.textDistances.right() * unitRatio);
+	firstLineOffsetComboBox->setCurrentIndex((int) prefsData->itemToolPrefs.firstLineOffset);
 
 	//Image Tool
 	imageFreeScalingRadioButton->setChecked( prefsData->itemToolPrefs.imageScaleType );
@@ -234,6 +243,7 @@ void Prefs_ItemTools::saveGuiToPrefs(struct ApplicationPrefs *prefsData) const
 	double unitRatio = unitGetRatioFromIndex(docUnitIndex);
 	prefsData->itemToolPrefs.textColumnGap = textColumnGapSpinBox->value() / unitRatio;
 	prefsData->itemToolPrefs.textTabWidth = textTabWidthSpinBox->value() / unitRatio;
+	prefsData->itemToolPrefs.firstLineOffset = (FirstLineOffsetPolicy) firstLineOffsetComboBox->currentIndex();
 
 	switch (textTabFillCharComboBox->currentIndex())
 	{
@@ -369,6 +379,7 @@ void Prefs_ItemTools::updateFontPreview()
 		return;
 
 	SampleItem si;
+	si.setDevicePixelRatio(devicePixelRatioF());
 	si.setText( tr("Woven silk pyjamas exchanged for blue quartz"));
 	if (textFrameFillColorComboBox->currentText() != CommonStrings::tr_NoneColor)
 	{
@@ -378,8 +389,8 @@ void Prefs_ItemTools::updateFontPreview()
 		}
 		else
 		{
-			PrefsManager& prefsManager=PrefsManager::instance();
-			ColorList* colorList=prefsManager.colorSetPtr();
+			PrefsManager& prefsManager = PrefsManager::instance();
+			ColorList* colorList = prefsManager.colorSetPtr();
 			si.setBgColor((*colorList)[textFrameFillColorComboBox->currentText()].getRawRGBColor());
 		}
 		si.setBgShade(textFrameFillShadingSpinBox->value());
@@ -395,8 +406,8 @@ void Prefs_ItemTools::updateFontPreview()
 		}
 		else
 		{
-			PrefsManager& prefsManager=PrefsManager::instance();
-			ColorList* colorList=prefsManager.colorSetPtr();
+			PrefsManager& prefsManager = PrefsManager::instance();
+			ColorList* colorList = prefsManager.colorSetPtr();
 			si.setTxColor((*colorList)[textColorComboBox->currentText()].getRawRGBColor());
 		}
 		si.setTxShade(textColorShadingSpinBox->value());
