@@ -53,7 +53,6 @@ Prefs_UserInterface::Prefs_UserInterface(QWidget* parent, ScribusDoc* doc)
 
 	connect(languageComboBox, SIGNAL(activated(const QString &)), this, SLOT(setSelectedGUILang(const QString &)));
 	connect(storyEditorFontPushButton, SIGNAL(clicked()), this, SLOT(changeStoryEditorFont()));
-	connect(storyEditorFontColorPushButton, SIGNAL(clicked()) , this, SLOT(changeStoryEditorFontColor()));
 }
 
 Prefs_UserInterface::~Prefs_UserInterface() = default;
@@ -108,52 +107,33 @@ void Prefs_UserInterface::restoreDefaults(struct ApplicationPrefs *prefsData)
 	storyEditorUseSmartSelectionCheckBox->setChecked(prefsData->storyEditorPrefs.smartTextSelection);
 	seFont.fromString(prefsData->storyEditorPrefs.guiFont);
 	storyEditorFontPushButton->setText(seFont.family());
-	QPixmap pm(100, 30);
-	pm.fill(prefsData->storyEditorPrefs.guiFontColorBackground);
-	seFontColor = prefsData->storyEditorPrefs.guiFontColorBackground;
-	storyEditorFontColorPushButton->setIcon(pm);
 }
 
 void Prefs_UserInterface::saveGuiToPrefs(struct ApplicationPrefs *prefsData) const
 {
-	prefsData->uiPrefs.language=selectedGUILang;
-	prefsData->uiPrefs.userPreferredLocale=numberFormatComboBox->currentData().toString();
-	prefsData->uiPrefs.style=themeComboBox->currentText();
-	prefsData->uiPrefs.iconSet=IconManager::instance().baseNameForTranslation(iconSetComboBox->currentText());
-	prefsData->uiPrefs.applicationFontSize=fontSizeMenuSpinBox->value();
-	prefsData->uiPrefs.paletteFontSize=fontSizePaletteSpinBox->value();
-	prefsData->uiPrefs.wheelJump=wheelJumpSpinBox->value();
-	prefsData->uiPrefs.mouseMoveTimeout=resizeMoveDelaySpinBox->value();
-	prefsData->uiPrefs.recentDocCount=recentDocumentsSpinBox->value();
-	prefsData->uiPrefs.showStartupDialog=showStartupDialogCheckBox->isChecked();
-	prefsData->uiPrefs.useTabs=useTabsForDocumentsCheckBox->isChecked();
-	prefsData->uiPrefs.showSplashOnStartup=showSplashCheckBox->isChecked();
-	prefsData->uiPrefs.useSmallWidgets=useSmallWidgetsCheckBox->isChecked();
+	prefsData->uiPrefs.language = selectedGUILang;
+	prefsData->uiPrefs.userPreferredLocale = numberFormatComboBox->currentData().toString();
+	prefsData->uiPrefs.style = themeComboBox->currentText();
+	prefsData->uiPrefs.iconSet = IconManager::instance().baseNameForTranslation(iconSetComboBox->currentText());
+	prefsData->uiPrefs.applicationFontSize = fontSizeMenuSpinBox->value();
+	prefsData->uiPrefs.paletteFontSize = fontSizePaletteSpinBox->value();
+	prefsData->uiPrefs.wheelJump = wheelJumpSpinBox->value();
+	prefsData->uiPrefs.mouseMoveTimeout = resizeMoveDelaySpinBox->value();
+	prefsData->uiPrefs.recentDocCount = recentDocumentsSpinBox->value();
+	prefsData->uiPrefs.showStartupDialog = showStartupDialogCheckBox->isChecked();
+	prefsData->uiPrefs.useTabs = useTabsForDocumentsCheckBox->isChecked();
+	prefsData->uiPrefs.showSplashOnStartup = showSplashCheckBox->isChecked();
+	prefsData->uiPrefs.useSmallWidgets = useSmallWidgetsCheckBox->isChecked();
 
-	prefsData->storyEditorPrefs.guiFont=seFont.toString();
-	prefsData->storyEditorPrefs.guiFontColorBackground=seFontColor;
-	prefsData->storyEditorPrefs.smartTextSelection=storyEditorUseSmartSelectionCheckBox->isChecked();
+	prefsData->storyEditorPrefs.guiFont = seFont.toString();
+	prefsData->storyEditorPrefs.smartTextSelection = storyEditorUseSmartSelectionCheckBox->isChecked();
 }
 
-
-void Prefs_UserInterface::setSelectedGUILang( const QString &newLang )
+void Prefs_UserInterface::setSelectedGUILang(const QString &newLang)
 {
 	selectedGUILang = LanguageManager::instance()->getAbbrevFromLang(newLang);
 }
 
-
-void Prefs_UserInterface::changeStoryEditorFontColor()
-{
-	QColor newColor(QColorDialog::getColor(seFontColor, this));
-	if (!newColor.isValid())
-		return;
-	QPixmap pm(100, 30);
-	pm.fill(newColor);
-	seFontColor = newColor;
-	storyEditorFontColorPushButton->setIcon(pm);
-}
-
-
 void Prefs_UserInterface::changeStoryEditorFont()
 {
 	bool ok;
