@@ -47,19 +47,21 @@ PropertiesPalette_Line::PropertiesPalette_Line( QWidget* parent) : QWidget(paren
 	startArrowLabel->setBuddy(startArrow);
 	endArrowLabel->setBuddy(endArrow);
 
-	startArrowScale->setMaximum( 1000 );
-	startArrowScale->setMinimum( 1 );
+	startArrow->setArrowDirection(ArrowDirection::StartArrow);
+	startArrowScale->setMaximum(1000);
+	startArrowScale->setMinimum(1);
 	startArrowScale->setDecimals(0);
 
-	endArrowScale->setMaximum( 1000 );
-	endArrowScale->setMinimum( 1 );
+	endArrow->setArrowDirection(ArrowDirection::EndArrow);
+	endArrowScale->setMaximum(1000);
+	endArrowScale->setMinimum(1);
 	endArrowScale->setDecimals(0);
 
 	lineWidthLabel->setBuddy(lineWidth);
 	lineJoinLabel->setBuddy(lineJoinStyle);
 	lineEndLabel->setBuddy(lineEndStyle);
 
-	lineStyles->setItemDelegate(new LineFormatItemDelegate);
+	lineStyles->setItemDelegate(new LineStyleItemDelegate());
 	lineStyles->addItem( "No Style" );
 
 	languageChange();
@@ -365,7 +367,7 @@ void PropertiesPalette_Line::updateLineStyles(ScribusDoc *doc)
 	{
 		QHash<QString,multiLine>::Iterator it;
 		for (it = doc->docLineStyles.begin(); it != doc->docLineStyles.end(); ++it)
-			lineStyles->addItem( new LineFormatItem(doc, it.value(), it.key()) );
+			lineStyles->addItem( new LineStyleItem(doc, it.value(), it.key()) );
 		lineStyles->sortItems();
 		lineStyles->insertItem( 0, tr("No Style"));
 		if (lineStyles->currentItem())
