@@ -25,9 +25,8 @@ for which a new license (GPL+exception) is in place.
 PropertyWidget_ParEffect::PropertyWidget_ParEffect(QWidget *parent) : QFrame(parent)
 {
 	setupUi(this);
-	setFrameStyle(QFrame::Box | QFrame::Plain);
-	setLineWidth(1);
-	layout()->setAlignment( Qt::AlignTop );
+
+	layout()->setAlignment(Qt::AlignTop);
 
 	languageChange();
 	dropCapLines->setValue(2);
