@@ -49,6 +49,7 @@ for which a new license (GPL+exception) is in place.
 #include "scimage.h"
 #include "scpaths.h"
 #include "scpreview.h"
+#include "scribusapp.h"
 #include "scribuscore.h"
 #include "util.h"
 #include "util_color.h"
@@ -716,19 +717,19 @@ void BibView::readContents(const QString& name)
 }
 
 /* This is the main Dialog-Class for the Scrapbook */
-Biblio::Biblio( QWidget* parent) : ScDockPalette(parent, "Sclib", nullptr)
+Biblio::Biblio(QWidget* parent) : ScDockPalette(parent, "Sclib", Qt::WindowFlags())
 {
-//	resize( 230, 190 );
 	setObjectName(QString::fromLocal8Bit("Sclib"));
+	setMinimumSize( QSize(220, 240) );
 	setSizePolicy( QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
 	containerWidget = new QWidget(this);
 	BiblioLayout = new QVBoxLayout( containerWidget );
-	BiblioLayout->setSpacing( 0 );
-	BiblioLayout->setMargin( 0 );
+	BiblioLayout->setSpacing(3);
+	BiblioLayout->setContentsMargins(3, 3, 3, 3);
 
 	buttonLayout = new QHBoxLayout;
-	buttonLayout->setSpacing( 5 );
-	buttonLayout->setMargin( 0 );
+	buttonLayout->setSpacing(3);
+	buttonLayout->setContentsMargins(0, 0, 0, 0);
 	newButton = new QToolButton(this);
 	newButton->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
 	newButton->setIcon(IconManager::instance().loadPixmap("16/document-new.png"));
@@ -747,8 +748,7 @@ Biblio::Biblio( QWidget* parent) : ScDockPalette(parent, "Sclib", nullptr)
 	closeButton->setIconSize(QSize(16, 16));
 	configButton = new QToolButton(this);
 	configButton->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
-	configButton->setIcon(IconManager::instance().loadPixmap("16/configure.png"));
-	configButton->setIconSize(QSize(16, 16));
+
 	configMenue = new QMenu();
 	conf_HideDirs = configMenue->addAction( tr("Hide Directories"));
 	conf_HideDirs->setCheckable(true);
@@ -793,6 +793,8 @@ Biblio::Biblio( QWidget* parent) : ScDockPalette(parent, "Sclib", nullptr)
 	conf_HideVectors->setChecked(m_prefs->getBool("hideVectors", false));
 	conf_OpenMode->setChecked(m_prefs->getBool("openMode", false));
 
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
+
 	connect(newButton, SIGNAL(clicked()), this, SLOT(newLib()));
 	connect(upButton, SIGNAL(clicked()), this, SLOT(goOneDirUp()));
 	connect(importButton, SIGNAL(clicked()), this, SLOT(Import()));
@@ -871,12 +873,12 @@ void Biblio::setScrapbookFileName(const QString& fileName)
 	activeBView->ScFilename=fileName;
 }
 
-const QString Biblio::getScrapbookFileName()
+const QString& Biblio::getScrapbookFileName()
 {
 	return activeBView->ScFilename;
 }
 
-const int Biblio::objectCount()
+int Biblio::objectCount()
 {
 	return activeBView->objectMap.count();
 }
@@ -1831,18 +1833,25 @@ void Biblio::objFromMenu(QString text)
 
 void Biblio::objFromCopyAction(const QString& text, const QString& name)
 {
-	QString nam;
+	// Something is bad with temp scrapbook directory, either it does not exists
+	// or is unreadeable, do not attempt to create temp scrapbook items in such case,
+	// they may end up in root directory or drive
+	if (tempBView->ScFilename.isEmpty())
+		return;
+	QString nativeTempScrapPath = QDir::toNativeSeparators(tempBView->ScFilename + "/");
+	QString nativeTempThumbsPath = QDir::toNativeSeparators(tempBView->ScFilename + "/.ScribusThumbs/");
+
 	QString tmp;
-	nam = name;
+	QString nam = name;
 	if (nam.isEmpty())
 		nam = tr("Object") + tmp.setNum(m_tempCount);
 	if (tempBView->objectMap.contains(nam))
 		nam += "("+ tmp.setNum(m_tempCount) + ")";
 	m_tempCount++;
-	tempBView->checkAndChange(text, QDir::cleanPath(QDir::toNativeSeparators(tempBView->ScFilename + "/" + nam + ".sce")), QDir::cleanPath(QDir::toNativeSeparators(tempBView->ScFilename)));
+	tempBView->checkAndChange(text, QDir::cleanPath(nativeTempScrapPath + nam + ".sce"), QDir::cleanPath(QDir::toNativeSeparators(tempBView->ScFilename)));
 	ScPreview *pre = new ScPreview();
 	QPixmap pm = QPixmap::fromImage(pre->createPreview(text));
-	tempBView->addObject(nam, QDir::cleanPath(QDir::toNativeSeparators(tempBView->ScFilename + "/" + nam + ".sce")), pm);
+	tempBView->addObject(nam, QDir::cleanPath(nativeTempScrapPath + nam + ".sce"), pm);
 	if (PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews)
 	{
 		QDir thumbs(tempBView->ScFilename);
@@ -1851,7 +1860,7 @@ void Biblio::objFromCopyAction(const QString& text, const QString& name)
 			if ((tempBView->canWrite) && (PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews))
 				thumbs.mkdir(".ScribusThumbs");
 		}
-		pm.save(QDir::cleanPath(QDir::toNativeSeparators(tempBView->ScFilename + "/.ScribusThumbs/" + nam +".png")), "PNG");
+		pm.save(QDir::cleanPath(nativeTempThumbsPath + nam +".png"), "PNG");
 	}
 	pm = pm.scaled(60, 60, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 	QPixmap pm2(60, 60);
@@ -1870,25 +1879,25 @@ void Biblio::objFromCopyAction(const QString& text, const QString& name)
 		it = tempBView->objectMap.begin();
 		QFile f(it.value().Data);
 		f.remove();
-		QFileInfo fi(QDir::toNativeSeparators(tempBView->ScFilename + "/.ScribusThumbs/" + it.key() + ".png"));
+		QFileInfo fi(nativeTempThumbsPath + it.key() + ".png");
 		if (fi.exists())
 		{
-			QFile f2(QDir::toNativeSeparators(tempBView->ScFilename + "/.ScribusThumbs/" + it.key() + ".png"));
+			QFile f2(nativeTempThumbsPath + it.key() + ".png");
 			f2.remove();
 		}
-		QFileInfo fiD(QDir::toNativeSeparators(tempBView->ScFilename + "/" + it.key()));
+		QFileInfo fiD(nativeTempScrapPath + it.key());
 		if ((fiD.exists()) && (fiD.isDir()))
 		{
 			QDir dd = QDir(QDir::toNativeSeparators(tempBView->ScFilename));
-			QDir d(QDir::toNativeSeparators(tempBView->ScFilename + "/" + it.key()), "*", QDir::Name, QDir::Files | QDir::Readable | QDir::NoSymLinks);
+			QDir d(nativeTempScrapPath + it.key(), "*", QDir::Name, QDir::Files | QDir::Readable | QDir::NoSymLinks);
 			if ((d.exists()) && (d.count() != 0))
 			{
 				for (uint dc = 0; dc < d.count(); ++dc)
 				{
-					QFile::remove(QDir::toNativeSeparators(tempBView->ScFilename + "/" + it.key() + "/" + d[dc]));
+					QFile::remove(nativeTempScrapPath + it.key() + "/" + d[dc]);
 				}
 			}
-			dd.rmdir(QDir::toNativeSeparators(tempBView->ScFilename + "/" + it.key()));
+			dd.rmdir(nativeTempScrapPath + it.key());
 		}
 		QString name = it.key();
 		tempBView->objectMap.erase(it);
@@ -1904,7 +1913,7 @@ void Biblio::objFromCopyAction(const QString& text, const QString& name)
 
 void Biblio::objFromMainMenu(QString text, int scrapID)
 {
-	QString nam = "";
+	QString nam;
 	QString tmp;
 	int scID = scrapID;
 	if (scID > 0)
@@ -1956,30 +1965,41 @@ void Biblio::objFromMainMenu(QString text, int scrapID)
 
 void Biblio::cleanUpTemp()
 {
+	// Something is bad with temp scrapbook directory, either it does not exists
+	// or is unreadeable, do not attempt to delete files in such case
+	if (tempBView->ScFilename.isEmpty())
+		return;
+	QString nativeScrapPath = QDir::toNativeSeparators(tempBView->ScFilename + "/");
+	QString nativeThumbsPath = QDir::toNativeSeparators(tempBView->ScFilename + "/.ScribusThumbs/");
+
 	QMap<QString,BibView::Elem>::Iterator it;
 	for (it = tempBView->objectMap.begin(); it != tempBView->objectMap.end(); ++it)
 	{
 		QFile f(it.value().Data);
 		f.remove();
-		QFileInfo fi(QDir::toNativeSeparators(tempBView->ScFilename + "/" + it.key() + ".png"));
-		if (fi.exists())
+		QFileInfo fi1(nativeScrapPath + it.key() + ".png");
+		if (fi1.exists())
 		{
-			QFile f2(QDir::toNativeSeparators(tempBView->ScFilename + "/" + it.key() + ".png"));
+			QFile f2(nativeScrapPath + it.key() + ".png");
 			f2.remove();
 		}
-		QFileInfo fiD(QDir::toNativeSeparators(tempBView->ScFilename + "/" + it.key()));
+		QFileInfo fi2(nativeThumbsPath + it.key() + ".png");
+		if (fi2.exists())
+		{
+			QFile f2(nativeThumbsPath + it.key() + ".png");
+			f2.remove();
+		}
+		QFileInfo fiD(nativeScrapPath + it.key());
 		if ((fiD.exists()) && (fiD.isDir()))
 		{
 			QDir dd = QDir(QDir::toNativeSeparators(tempBView->ScFilename));
-			QDir d(QDir::toNativeSeparators(tempBView->ScFilename + "/" + it.key()), "*", QDir::Name, QDir::Files | QDir::Readable | QDir::NoSymLinks);
+			QDir d(nativeScrapPath + it.key(), "*", QDir::Name, QDir::Files | QDir::Readable | QDir::NoSymLinks);
 			if ((d.exists()) && (d.count() != 0))
 			{
 				for (uint dc = 0; dc < d.count(); ++dc)
-				{
-					QFile::remove(QDir::toNativeSeparators(tempBView->ScFilename + "/" + it.key() + "/" + d[dc]));
-				}
+					QFile::remove(nativeScrapPath + it.key() + "/" + d[dc]);
 			}
-			dd.rmdir(QDir::toNativeSeparators(tempBView->ScFilename + "/" + it.key()));
+			dd.rmdir(nativeScrapPath + it.key());
 		}
 	}
 }
@@ -1992,6 +2012,26 @@ void Biblio::changeEvent(QEvent *e)
 		ScDockPalette::changeEvent(e);
 }
 
+void Biblio::iconSetChange()
+{
+	IconManager& iconManager = IconManager::instance();
+
+	newButton->setIcon(iconManager.loadPixmap("16/document-new.png"));
+	newButton->setIconSize(QSize(16, 16));
+
+	upButton->setIcon(iconManager.loadPixmap("16/go-up.png"));
+	upButton->setIconSize(QSize(16, 16));
+
+	importButton->setIcon(iconManager.loadPixmap("compfile16.png"));
+	importButton->setIconSize(QSize(16, 16));
+
+	closeButton->setIcon(iconManager.loadPixmap("16/close.png"));
+	closeButton->setIconSize(QSize(16, 16));
+
+	configButton->setIcon(iconManager.loadPixmap("16/configure.png"));
+	configButton->setIconSize(QSize(16, 16));
+}
+
 void Biblio::languageChange()
 {
 	setWindowTitle( tr( "Scrapbook" ) );
